@@ -20,15 +20,20 @@ applications that work with the CPANTS data.
 use 5.008005;
 use strict;
 use warnings;
-use File::Spec                            ();
-use File::HomeDir                         ();
-use File::ShareDir                        ();
-use Algorithm::Dependency 1.108           ();
-use Algorithm::Dependency::Weight         ();
-use Algorithm::Dependency::Source::DBI    ();
-use Algorithm::Dependency::Source::Invert ();
+use File::Spec                              ();
+use File::HomeDir                      0.82 ();
+use File::ShareDir                     1.00 ();
+use Algorithm::Dependency             1.108 ();
+use Algorithm::Dependency::Weight           ();
+use Algorithm::Dependency::Source::DBI 0.05 ();
+use Algorithm::Dependency::Source::Invert   ();
 
-our $VERSION = '0.02';
+our $VERSION = '0.06';
+
+our $DEBUG;
+sub trace {
+	print STDERR "# $_[0]\n" if $DEBUG;
+}
 
 use constant ORLITE_FILE => File::Spec->catfile(
 	File::HomeDir->my_data,
@@ -47,11 +52,11 @@ use ORLite::Migrate 0.02 {
 	file         => ORLITE_FILE,
 	create       => 1,
 	timeline     => ORLITE_TIMELINE,
-	user_version => 1,
+	user_version => 2,
 };
 
 # Load the CPANTS database (This could take a while...)
-use ORDB::CPANTS;
+use ORDB::CPANTS 0.03;
 
 # Common string fragments
 my $SELECT_IDS = <<'END_SQL';
@@ -118,27 +123,31 @@ sub run {
 	# }
 
 	# Prefetch the author and dist lists
+	trace("Loading CPANTS Authors...");
 	my @authors = ORDB::CPANTS::Author->select(
 		'where pauseid is not null'
 	);
+	trace("Loading CPANTS Distributions...");
 	my @dists = ORDB::CPANTS::Dist->select(
 		'where author not in ( select id from author where pauseid is null )'
 	);
-
-	# Indexed table of weighting scores
-	my $weight     = $self->algorithm_weight->weight_all;
-	my $volatility = $self->algorithm_volatility->weight_all;
-
-	# Indexed table of kwalitee data
+	trace("Loading Kwalitee...");
 	my $kwalitee   = ORDB::CPANTS->selectall_hashref(
 		'select * from kwalitee',
 		'dist',
 	);
 
+	# Indexed table of weighting scores
+	trace("Precalculating weight...");
+	my $weight     = $self->algorithm_weight->weight_all;
+	trace("Precalculating volatility...");
+	my $volatility = $self->algorithm_volatility->weight_all;
+
 	# Populate the AuthorWeight objects
+	trace("Populating Author metrics...");
 	CPANTS::Weight->begin;
 	CPANTS::Weight::AuthorWeight->truncate;
-	foreach my $author ( @authors ) {
+	foreach my $author ( @authors ) { ### Authors [===|    ] % done
 		# Find the list of distros for this author
 		my $id     = $author->id;
 		# my @ids    = grep { $_->author } @dists;
@@ -151,19 +160,47 @@ sub run {
 	CPANTS::Weight->commit;
 
 	# Populate the DistWeight objects
+	trace("Populating Distribution metrics...");
 	CPANTS::Weight->begin;
 	CPANTS::Weight::DistWeight->truncate;
-	foreach my $dist ( @dists ) {
+	foreach my $dist ( @dists ) { ### Distributions [===|    ] % done
 		my $id = $dist->id;
 		my $k  = $kwalitee->{$id} || {};
+
+		# Does this distribution make life difficult
+		# for downstream packagers.
+		my $enemy_downstream = $k->{easily_repackagable} ? 0 : 1;
+
+		# Is this distribution popular, but NOT provided in
+		# Debian, making it a good candidate for packaging.
+		my $debian_candidate = $k->{distributed_by_debian} ? 0 : 1;
+
+		# Does this distribution supply useful metadata.
+		# Level 1 requires a parsable META.yml file
+		# Level 2 requires META.yml conforms to a known specification,
+		# and has a license declaration.
+		# Level 3 requires META.yml conform to the current specification,
+		# and declares the required minimum Perl version.
+		my $meta1 = ($k->{has_meta_yml} and $k->{metayml_parsable}) ? 0 : 1;
+		my $meta2 = ($k->{metayml_conforms_to_known_spec} and $k->{metayml_has_license}) ? 0 : 1;
+		my $meta3 = ($k->{metayml_conforms_current_spec} and $k->{metayml_declares_perl_version}) ? 0 : 1;
+		if ( $meta1 ) {
+			$meta2 = 0;
+		}
+		if ( $meta1 or $meta2 ) {
+			$meta3 = 0;
+		}
 		CPANTS::Weight::DistWeight->create(
 			id               => $id,
 			dist             => $dist->dist,
 			author           => $dist->author,
 			weight           => $weight->{$id},
 			volatility       => $volatility->{$id},
-			enemy_downstream => $k->{easily_repackagable}   ? 1 : 0,
-			debian_candidate => $k->{distributed_by_debian} ? 0 : 1,
+			enemy_downstream => $enemy_downstream,
+			debian_candidate => $debian_candidate,
+			meta1            => $meta1,
+			meta2            => $meta2,
+			meta3            => $meta3,
 		);
 	}
 	CPANTS::Weight->commit;
